LogStreamer

Trait LogStreamer 

pub trait LogStreamer: Send + Sync {
    // Required method
    fn stream_logs<'life0, 'life1, 'async_trait>(
        &'life0 self,
        id: &'life1 str,
        options: LogOptions,
    ) -> Pin<Box<dyn Future<Output = AppResult<BoxStream<'static, AppResult<String>>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
Implemented by backends that can stream log lines in real time.

Required Methods

fn stream_logs<'life0, 'life1, 'async_trait>( &'life0 self, id: &'life1 str, options: LogOptions, ) -> Pin<Box<dyn Future<Output = AppResult<BoxStream<'static, AppResult<String>>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Stream log lines for the workload identified by id.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors