Module report

Module report 

Runtime state and result reports. Runtime state and result reports returned by a crate::Manager.

Structs

DeployResult
Returned after a successful deployment.
DiskUsage
Storage consumption reported by a backend runtime.
ExecResult
Result of running a command inside a workload.
GpuInfo
A GPU detected by a backend runtime.
ImageConfig
Selected container configuration held in an image.
ImageDetail
Detailed metadata for a single image.
ImageDiskEntry
A single image in a DiskUsage breakdown.
ImageEvent
An image lifecycle event reported by a backend runtime.
SystemInfo
Host-level information about a backend runtime.
WaitResult
Returned when a workload exits.
WorkloadEvent
A workload lifecycle event.
WorkloadInfo
Summary information returned by list operations.
WorkloadStats
Resource usage statistics.
WorkloadStatus
Detailed status of a single workload.