Module state

Module state 

Workload runtime state and restart policy. Workload runtime state and restart policy.

Enums

RestartPolicy
Policy governing whether a workload is restarted after it exits.
WorkloadState
Lifecycle state of a workload as reported by a provider.