#[non_exhaustive]pub enum WorkloadState {
Created,
Running,
Stopped,
Completed,
Error,
Restarting,
Unknown,
NotFound,
}Expand description
Lifecycle state of a workload as reported by a provider.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Created
Created but not yet started.
Running
Running.
Stopped
Stopped by request.
Completed
Ran to completion successfully.
Error
Terminated with an error.
Restarting
Restarting.
Unknown
State could not be determined.
NotFound
No such workload exists.
Implementations
Sourceimpl WorkloadState
impl WorkloadState
Sourcepub const fn is_running(self) -> bool
pub const fn is_running(self) -> bool
Returns true when the workload is actively running.
Sourcepub const fn is_terminal(self) -> bool
pub const fn is_terminal(self) -> bool
Returns true when the workload has reached a terminal state.