Runtime state and result reports.
Runtime state and result reports returned by a crate::Manager.
Structs
- Deploy
Result - Returned after a successful deployment.
- Disk
Usage - Storage consumption reported by a backend runtime.
- Exec
Result - Result of running a command inside a workload.
- GpuInfo
- A GPU detected by a backend runtime.
- Image
Config - Selected container configuration held in an image.
- Image
Detail - Detailed metadata for a single image.
- Image
Disk Entry - A single image in a
DiskUsagebreakdown. - Image
Event - An image lifecycle event reported by a backend runtime.
- System
Info - Host-level information about a backend runtime.
- Wait
Result - Returned when a workload exits.
- Workload
Event - A workload lifecycle event.
- Workload
Info - Summary information returned by list operations.
- Workload
Stats - Resource usage statistics.
- Workload
Status - Detailed status of a single workload.